#
#     Setting up a variable to specify the location of your final images
#     makes your script easier to read and more portable when you share it
#     with other users
#
import csv

myUser="username"

#
#     Windows XP
#
#imageDir=("C:\\Documents and Settings\\"+myUser+"\\McIDAS-V\\")

#
#     Windows 7 example
#
imageDir=('C:\\Users\\'+myUser+'\\McIDAS-V\\')

#
#     Unix
#
#imageDir=("/home/"+myUser+"/McIDAS-V/")

#
#     OS X example
#
#imageDir=('/Users/'+myUser+'/Documents/McIDAS-V/')

#
#     The easiest way to make an ADDE request is to create a dictionary
#     That defines your parameters.  Here we have a generic request
# 
desc = getLocalADDEEntry('GOES-13', 'Pixel Classification Dataset')
adde_parms = dict(
    server='localhost',
    localEntry=desc,
    place=Places.CENTER,
    size=(100,200),
    coordinateSystem=LATLON,
    location=(44.0,-100.0),
    mag=(1, 1),
    unit='TEMP',
)


outputFile = open(imageDir+"stats.txt", "w") 
csvFile = open(imageDir+"stats.csv", "wb") 
csvData = csv.writer(csvFile, delimiter=",")
csvData.writerow(["Time", "latitude", "longitude", "geometricMean", "min", "median", "max", "kurtosis", "numPoints", "skewness", "stdDev", "variance"])

#
#     Now make the request using the function loadADDEImage
#     This returns an object containing data and metadata
#
for pos in range(-4,1):
    irData = loadADDEImage(position=(pos),band=4, **adde_parms)

#
#     pass the irData into the Statistics package
#
    stats=Statistics(irData)

#
#     open a file and write out the statistics data
#
    outputFile.write("   stat and value for: %s \n" % irData["nominal-time"])
    outputFile.write("   geometric mean: %s \n" % stats.geometricMean())
    outputFile.write("   kurtosis: %s \n" % stats.kurtosis())
    outputFile.write("   num points: %s \n" % stats.numPoints())
    outputFile.write("   skewness: %s \n" % stats.skewness())
    outputFile.write("   std dev: %s \n" % stats.standardDeviation())
    outputFile.write("   variance: %s \n" % stats.variance())
    outputFile.write("\n")

#
#     import the csv library for writing out the 
#     statistics values
#
    theTime = str(irData["nominal-time"])[11:16]
    csvData.writerow([theTime, "44.0", "-100.0", stats.geometricMean(), stats.min(), stats.median(), stats.max(), stats.kurtosis(),
        stats.numPoints(), stats.skewness(), stats.standardDeviation(), stats.variance()])

csvFile.close()
outputFile.close()

#
#     The last section of the script will annotate an image
#     with the information from the statistics package.
#
#     Now make the request using the function loadADDEImage.
#     This returns an object containing data and metadata.
#
irData = loadADDEImage(position=-1, band=4, **adde_parms)

#
#     pass the irData into the Statistics package for this image
#
statsimage=Statistics(irData) 

#     Create some strings from the data object to be able
#     to annotate our window with the stats values.
#
min = 'min: %s' % (
    statsimage.min()
    )
max = 'max: %s' % (
    statsimage.max()
    )
stddev = 'std dev: %s' % (
    statsimage.standardDeviation()
    )
geomean = 'geometric mean: %s' % (
    statsimage.geometricMean()
    )
numpoints = 'num points: %s' % (
    statsimage.numPoints()
    )

#     Create a string from the data to make it 
#     easier to label the image.
#
irLabel = '%s %s' % (
    irData['sensor-type'],
    irData['nominal-time']
    )

#     
#     Build a window with a single panel 
#
panel = buildWindow(height=600,width=900)

#
#     Create a layer from the infrared data object 
#
irLayer = panel[0].createLayer('Image Display', irData)

#
#     When changing attributes, some are panel based and
#     others are layer based.  In the following steps, they are:
# 
#     Change the projection (panel)
#     Turn off the wire frame box (panel)
#     Change the center point (panel)
#     Add the statistics values (panel)
#     Add a layer label (layer)
#     Save the output file (panel)
#
panel[0].setProjection('US>States>N-Z>South Dakota')
panel[0].setWireframe(False)
panel[0].setCenter(44.5,-100.0, scale=1.0)
panel[0].annotate(min, line=26,element=170, size=18, color='Blue')
panel[0].annotate(max, line=44,element=170, size=18, color='Blue')
panel[0].annotate(stddev, line=62,element=170, size=18, color='Blue')
panel[0].annotate(geomean, line=80,element=170, size=18, color='Blue')
panel[0].annotate(numpoints, line=98,element=170, size=18, color='Blue')
irLayer.setLayerLabel(label=irLabel, size=14)
panel[0].captureImage(imageDir+'stats-image.jpg')
